@@ -22,7 +22,6 @@ def make_gitlab_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
     hostname="gitlab.com",
 ):
@@ -30,7 +29,8 @@ def make_gitlab_blueprint(
     Make a blueprint for authenticating with GitLab using OAuth 2. This requires
     a client ID and client secret from GitLab. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables GITLAB_OAUTH_CLIENT_ID and GITLAB_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`GITLAB_OAUTH_CLIENT_ID` and
+    :envvar:`GITLAB_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on GitLab.
@@ -73,7 +73,6 @@ def make_gitlab_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     gitlab_bp.from_config["client_id"] = "GITLAB_OAUTH_CLIENT_ID"
