@@ -22,14 +22,14 @@ def make_spotify_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with Spotify using OAuth 2. This requires
     a client ID and client secret from Spotify. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables SPOTIFY_OAUTH_CLIENT_ID and SPOTIFY_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`SPOTIFY_OAUTH_CLIENT_ID` and
+    :envvar:`SPOTIFY_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on Spotify.
@@ -68,7 +68,6 @@ def make_spotify_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     spotify_bp.from_config["client_id"] = "SPOTIFY_OAUTH_CLIENT_ID"
